<?php

namespace Bixo\Whatsapp\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Whatsapp\Events\ChatWorkflow as ChatWorkflowEvent;
use Bixo\Whatsapp\Notifications\ChatWorkflow as ChatWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ChatWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ChatWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $chat is submitted.
     *
     * @param ChatWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ChatWorkflowEvent $event)
    {
        $client = $event->chat->client;
        Notification::send($client, new ChatWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $chat is published.
     *
     * @param ChatWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ChatWorkflowEvent $event)
    {
        $client = $event->chat->client;
        Notification::send($client, new ChatWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $chat is approved.
     *
     * @param ChatWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ChatWorkflowEvent $event)
    {
        $client = $event->chat->client;
        Notification::send($client, new ChatWorkflowNotification($event));
    }

    /**
     * Handles the $chat workflow event as a listener.
     *
     * @param ChatWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ChatWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
