<?php

namespace Bixo\Whatsapp\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Whatsapp\Models\Chat;

class ChatPolicy
{


    /**
     * Determine if the given user can view the chat.
     *
     * @param Authenticatable $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function view(Authenticatable $user, Chat $chat)
    {
        if ($authUser->canDo('whatsapp.chat.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $chat->is_owner;
    }

    /**
     * Determine if the given user can create a chat.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('whatsapp.chat.create');
    }

    /**
     * Determine if the given user can update the given chat.
     *
     * @param Authenticatable $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function update(Authenticatable $user, Chat $chat)
    {
        if ($user->canDo('whatsapp.chat.edit') && $user->isAdmin()) {
            return true;
        }

        return $chat->is_owner;
    }

    /**
     * Determine if the given user can delete the given chat.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Chat $chat)
    {
        return $chat->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
