<?php

namespace Bixo\Whatsapp\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Whatsapp\Whatsapps;

class WhatsappServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'whatsapp');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'whatsapp');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();

        $this->app->register(\Bixo\Whatsapp\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Whatsapp\Providers\RouteServiceProvider::class);
    }


    /**
     * Merges user's and whatsapp's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.whatsapp'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/user.php', 'bixo.whatsapp.user'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/chat.php', 'bixo.whatsapp.chat'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.whatsapp'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/whatsapp')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/whatsapp')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/whatsapp')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
